collect_bio_layer.collect_hipathia_pathway()

Collecting HiPathia pathway information for the given species and export into given data folder.

Usage

collect_bio_layer.collect_hipathia_pathway(
    species,
    path_data_raw,
)

species : str The species identifier (e.g., ‘hsa’ for homo sapiens, ‘mmu’ for mus musculus) path_data_raw : str Folder location, the unfiltered pathway list will be exported

df_pathway : pd.DataFrame DataFrame containing collected pathway information