collect_bio_layer.create_pbk_matrix_hipathia_signaling()

Exporting pathway and circuit dataset. The exported data gene vs pathway/circuit. It shows the connection details of each pathway-gene and circuit-gene pairs.

Usage

collect_bio_layer.create_pbk_matrix_hipathia_signaling(
    species, processed, export_circuit
)

The exported files are the main prior biological knowledge information and can be used for integrating with desired neural network.

species : str The organism detail processed : str The file location, the filtered pathway list will be exported into this given location export_circuit : bool The list of keyword which will be used for a PARTIAL matching


Two dataset is exporting for both pathway and circuit