collect_bio_layer.remove_disease_pathways()
Removing disease-associated pathways from collected data. The data, by default, is collecting from HiPathia package. The raw data (input_pathway) is a list of pathway name and ID pairs.
Usage
collect_bio_layer.remove_disease_pathways(
input_pathway, output_folder, disease_keyword, disease_list
)This function reads the collected raw pairs and removes the pathway if it does exist in any of the given list (disease_keyword or disease_list). Both list has same tasks which searches the raw list and checks for any matching pathway within given lists. Only difference is the matching type, means that the disease_keyword does look for a PARTIAL matching while disease_list does look for an EXACT matching.
input_pathway : str The collected pathway information output_folder : str The file location, the filtered pathway list will be exported into this given location disease_keyword : list The list of keyword which will be used for a PARTIAL matching disease_list : list The list of pathway name which will be used for an EXACT matching
df_pathway : pd.DataFrame The list of disease-associated-free pathway