default_pbk_hipathia.process_default_pbk()

The main script that collects and export the signaling pathway/circut matrix.

Usage

default_pbk_hipathia.process_default_pbk(
    species, default_disease_keyword, default_disease_list
)

This script calls all important script in sequence.

Parameters

species

str The organism name, default values are hsa for homo sapiens and mmu for mus musculus

default_disease_keyword

List A list of disease-associated wordings. The items in this list are using as a seach term in the list of signaling pathway. If there is a partial-match, then the pathway is elimating from the final list.

default_disease_list
List A list of disease-associated pathway. The items in this list are using as a seach term in the list of signaling pathway. If there is an exact match, then the pathway is elimating from the final list.

Returns

It exports data_spn_helper folder and the final matrices for both pathway and cirucit detail

. [PARENT_FOLDER]

├── ….

├── data_spn_helper

│ ├── processed

│ │ └── {SPECIES}

│ │ ├── entrez_and_symbol.csv

│ │ ├── hipathia_details

│ │ │ ├── hsa03320_gene_list.txt

│ │ │ ├── ……. [GENE LIST for EACH INDIVIDUAL PATHWAY]

│ │ │ └── hsa05100_gene_list.txt

│ │ ├── hipathia_gene_list.csv

│ │ ├── hipathia_pathway_ids_and_names.csv

│ │ ├── hsc_pbk_hsa.txt <—- PATHWAY x GENE DETAIL

│ │ └── hsp_pbk_hsa.txt <—- CIRCUIT x GENE DETAIL

│ └── raw

│ └── {SPECIES}

│ ├── hipathia_gene_list_all.csv

│ └── hipathia_pathway_ids_and_names.csv

└── ….