package_env_manager.load_dependencies()
Locate and parse the dependencies.yml file which contains
Usage
package_env_manager.load_dependencies()the list of package which are essential for the package.
Locate and parse the dependencies.yml file which contains
Usage
the list of package which are essential for the package.