py_collect_gene_entrezid.py_gene_id_entrez_converter()

Calling helper R-script to collect gene from HiPathia package.

Usage

py_collect_gene_entrezid.py_gene_id_entrez_converter(
    species, genome_annotation, processed
)

IMPORTANT NOTES, genome_annotation parameter gets ‘Genome wide annotation’. The naming should be same as defined in ‘Bioconductor AnnotationData Package’ website. Please check given website for more detail — https://bioconductor.org/packages/3.23/data/annotation

Please check given function for more detail, hipathia/r_collect_gene_entrezid.r –>> gene_id_entrez_converter

species : str The species identifier (e.g., ‘hsa’ for homo sapiens, ‘mmu’ for mus musculus) genome_annotation : str Genome wide annotation keyword detail processed : str Folder location, the filtered gene list file will be exported into given location


The returns entrez id - gene name pair. This dataset is using as a look-up table to collect the proper matching for gene-pathway/circuit pairs
    data_spn_helper/processed/{SPECIES}/entrez_and_symbol.csv