py_collect_gene_entrezid.py_gene_from_hipathia()
Calling helper R-script to collect gene from HiPathia package.
Usage
py_collect_gene_entrezid.py_gene_from_hipathia(
species,
raw,
processed,
)Please check given function for more detail, hipathia/r_collect_gene_entrezid.r –>> gene_from_hipathia
species : str The species identifier (e.g., ‘hsa’ for homo sapiens, ‘mmu’ for mus musculus) raw : str Folder location, the raw gene list file location processed : str Folder location, the filtered gene list file will be exported into given location
Each individual gene-circuit detail for each pathway. The files will be exporting into
data_spn_helper/processed/{SPECIES}/hipathia_detail/[PATHWAY_ID]_gene_list.txt